@@ -5,7 +5,7 @@
 
     * getting a url's full public bookmarking history including
         * users who bookmarked the url including tags used for such bookmarks
-      	  and the creation time of the bookmark (up to YYYY-MM-DD granularity)
+          and the creation time of the bookmark (up to YYYY-MM-DD granularity)
         * top tags (up to a maximum of 10) including tag count
         * title as stored on delicious.com
         * total number of bookmarks/users for this url at delicious.com
@@ -34,19 +34,22 @@
     More information about this module can be found at
     http://www.michael-noll.com/wiki/Del.icio.us_Python_API
 
-    Copyright 2006-2008 Michael G. Noll <http://www.michael-noll.com/>
+    Changelog is available at
+    http://code.michael-noll.com/?p=deliciousapi;a=log
+
+    Copyright 2006-2009 Michael G. Noll <http://www.michael-noll.com/>
 
 """
 
 __author__ = "Michael G. Noll"
-__copyright__ = "(c) 2006-2008 Michael G. Noll"
+__copyright__ = "(c) 2006-2009 Michael G. Noll"
 __description__ = "Unofficial Python API for retrieving data from del.icio.us / delicious.com"
 __email__ = "coding[AT]michael-REMOVEME-noll[DOT]com"
 __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.4.2"
+__version__ = "1.5.5"
 
 import base64
 import cgi
@@ -323,6 +326,7 @@ class DeliciousAPI(object):
                 f = opener.open(url)
                 data = f.read()
                 f.close()
+                break
             except urllib2.HTTPError, e:
                 if e.code == 301:
                     raise DeliciousMovedPermanentlyWarning, "delicious.com status %s - url moved permanently" % e.code
@@ -395,6 +399,8 @@ class DeliciousAPI(object):
                 urlinfo = simplejson.loads(data)
                 if urlinfo:
                     urlinfo = urlinfo[0]
+                else:
+                    urlinfo = {}
             except TypeError:
                 pass
             try:
